@@ -451,6 +451,18 @@ class BasicDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {FundStatusLatest.__tablename__}')
 
+    def get_inside_market_funds(self):
+        fund_status_latest = self.get_fund_status()
+        in_market_fund_list = fund_status_latest[~fund_status_latest['trade_status'].isnull()].fund_id.tolist()
+        fund_info = self.get_fund_info()
+        return fund_info[fund_info.fund_id.isin(in_market_fund_list)]
+
+    def get_outside_market_funds(self):
+        fund_status_latest = self.get_fund_status()
+        in_market_fund_list = fund_status_latest[~fund_status_latest['trade_status'].isnull()].fund_id.tolist()
+        fund_info = self.get_fund_info()
+        return fund_info[~fund_info.fund_id.isin(in_market_fund_list)]
+
     def get_fund_conv_stats(self):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
