@@ -421,10 +421,7 @@ class RawDataApi(metaclass=Singleton):
         with RawDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
-                    EmFundScale.CODES,
-                    EmFundScale.DATES,
-                    EmFundScale.FUNDSCALE,
-                    EmFundScale.UNITTOTAL,
+                    EmFundScale,
                 )
                 if start_date:
                     query = query.filter(
@@ -437,21 +434,36 @@ class RawDataApi(metaclass=Singleton):
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get scale data <err_msg> {e} from {EmFundScale.__tablename__}')
-                return None
+                return
+
+    def delete_em_fund_scale(self, date_to_delete: datetime.date, fund_list: List[str]):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                db_session.query(
+                    EmFundScale
+                ).filter(
+                    EmFundScale.CODES.in_(fund_list),
+                    EmFundScale.DATES == date_to_delete,
+                ).delete(synchronize_session=False)
+                db_session.commit()
+                return True
+            except Exception as e:
+                print(f'Failed to delete data <err_msg> {e} from {EmFundScale.__tablename__}')
+                return False
 
     def get_em_fund_status(self, end_date: str = ''):
         with RawDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
-                    EmFundScale
+                    EmFundStatus
                 )
                 if end_date:
                     query = query.filter(
-                        EmFundScale.DATES <= end_date,
+                        EmFundStatus.DATES <= end_date,
                     )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
-                print(f'Failed to get data <err_msg> {e} from {EmFundScale.__tablename__}')
+                print(f'Failed to get data <err_msg> {e} from {EmFundStatus.__tablename__}')
                 return None
 
     def get_em_stock_price(self, start_date: str = '', end_date: str = '', stock_list: Tuple[str] = (), columns: Tuple[str] = ()):
@@ -976,6 +988,21 @@ class RawDataApi(metaclass=Singleton):
                 print(f'Failed to delete data <err_msg> {e} from {EMFundHoldIndustry.__tablename__}')
                 return False
 
+    def delete_em_fund_hold_industry_qdii(self, date_to_delete: datetime.date, fund_list: List[str]):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                db_session.query(
+                    EMFundHoldIndustryQDII
+                ).filter(
+                    EMFundHoldIndustryQDII.CODES.in_(fund_list),
+                    EMFundHoldIndustryQDII.DATES == date_to_delete,
+                ).delete(synchronize_session=False)
+                db_session.commit()
+                return True
+            except Exception as e:
+                print(f'Failed to delete data <err_msg> {e} from {EMFundHoldIndustryQDII.__tablename__}')
+                return False
+
     def get_em_fund_hold_stock(self, start_date: str = '', end_date: str = '', fund_ids: Tuple[str] = ()):
         with RawDatabaseConnector().managed_session() as raw_session:
             try:
@@ -997,6 +1024,48 @@ class RawDataApi(metaclass=Singleton):
                 print(f'Failed to get data <err_msg> {e} from {EMFundHoldStock.__tablename__}')
                 return None
 
+    def get_em_fund_hold_industry_qdii(self, start_date: str = '', end_date: str = '', fund_ids: Tuple[str] = ()):
+        with RawDatabaseConnector().managed_session() as raw_session:
+            try:
+                query = raw_session.query(EMFundHoldIndustryQDII)
+                if fund_ids:
+                    query = query.filter(
+                        EMFundHoldIndustryQDII.CODES.in_(fund_ids),
+                    )
+                if start_date:
+                    query = query.filter(
+                        EMFundHoldIndustryQDII.DATES >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
+                        EMFundHoldIndustryQDII.DATES <= end_date,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {EMFundHoldIndustryQDII.__tablename__}')
+                return None
+
+    def get_em_fund_hold_stock_qdii(self, start_date: str = '', end_date: str = '', fund_ids: Tuple[str] = ()):
+        with RawDatabaseConnector().managed_session() as raw_session:
+            try:
+                query = raw_session.query(EMFundHoldStockQDII)
+                if fund_ids:
+                    query = query.filter(
+                        EMFundHoldStockQDII.CODES.in_(fund_ids),
+                    )
+                if start_date:
+                    query = query.filter(
+                        EMFundHoldStockQDII.DATES >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
+                        EMFundHoldStockQDII.DATES <= end_date,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {EMFundHoldStockQDII.__tablename__}')
+                return None
+
     def delete_em_fund_hold_stock(self, date_to_delete: datetime.date, fund_list: List[str]):
         with RawDatabaseConnector().managed_session() as db_session:
             try:
@@ -1012,6 +1081,21 @@ class RawDataApi(metaclass=Singleton):
                 print(f'Failed to delete data <err_msg> {e} from {EMFundHoldStock.__tablename__}')
                 return False
 
+    def delete_em_fund_hold_stock_qdii(self, date_to_delete: datetime.date, fund_list: List[str]):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                db_session.query(
+                    EMFundHoldStockQDII
+                ).filter(
+                    EMFundHoldStockQDII.CODES.in_(fund_list),
+                    EMFundHoldStockQDII.DATES == date_to_delete,
+                ).delete(synchronize_session=False)
+                db_session.commit()
+                return True
+            except Exception as e:
+                print(f'Failed to delete data <err_msg> {e} from {EMFundHoldStockQDII.__tablename__}')
+                return False
+
     def get_em_fund_hold_bond(self, start_date: str = '', end_date: str = '', fund_ids: Tuple[str] = ()):
         with RawDatabaseConnector().managed_session() as raw_session:
             try:
