@@ -1052,9 +1052,37 @@ class BasicDataPart1:
         bond_fund['datetime'] = dt
         bond_fund = pd.merge(bond_fund, fund_info[['fund_id','desc_name']].rename(columns={'desc_name':'fund_name'}), on ='fund_id')
         # 海外债券简称未处理，过长，仅展示国内债券
-        bond_fund = bond_fund[bond_fund.stock_id.str.contains('.SH') | bond_fund.stock_id.str.contains('.SZ') ｜ bond_fund.stock_id.str.contains('.IB')]
+        bond_fund = bond_fund[bond_fund.stock_id.str.contains('.SH') | bond_fund.stock_id.str.contains('.SZ') | bond_fund.stock_id.str.contains('.IB')]
         self._data_helper._upload_basic(bond_fund, BondInFund.__table__.name)
 
+    def etf_info(self):
+        def main_index(x):
+            if x == '':
+                return None
+            x = json.loads(x)
+            x = sorted(x.items(), key=lambda x:x[1], reverse=True)[0][0]
+            if x == '-1':
+                return None
+            return x
+        
+        benchmark_info = self._basic_data_api.get_fund_benchmark()
+        inside_market_fund = self._basic_data_api.get_inside_market_funds()
+        outside_market_funds = self._basic_data_api.get_outside_market_funds()
+        index_info = self._basic_data_api.get_index_info()
+
+        inside_market_fund = inside_market_fund[inside_market_fund.desc_name.str.contains('ETF')]
+        outside_market_funds = outside_market_funds[outside_market_funds.desc_name.str.contains('ETF')]
+        benchmark_info['main_index'] = benchmark_info.benchmark_s.map(lambda x : main_index(x))
+        df = pd.merge(inside_market_fund, benchmark_info[['fund_id','main_index']], on=['fund_id'])
+        in_market = df[['fund_id','desc_name','wind_class_1','wind_class_2','company_id','main_index']].rename(columns={'main_index':'index_id'})
+        in_market['etf_type'] = '场内'
+        df = pd.merge(outside_market_funds, benchmark_info[['fund_id','main_index']], on=['fund_id'])
+        out_market = df[['fund_id','desc_name','wind_class_1','wind_class_2','company_id','main_index']].rename(columns={'main_index':'index_id'})
+        out_market['etf_type'] = '场外'
+        result = pd.concat([in_market,out_market], axis=0)
+        result = pd.merge(result, index_info[['index_id','desc_name']].rename(columns={'desc_name':"index_name"}), on='index_id')
+        self._data_helper._upload_basic(result, ETFInfo.__table__.name)
+
     def process_all(self, start_date, end_date):
         failed_tasks = []
         # Depend on RQ
