@@ -1,3 +1,6 @@
+
+import traceback
+
 from .basic_data_part1 import BasicDataPart1
 from .basic_data_part2_fund_ret import BasicFundRet
 from .style_analysis_data import StockFactor
@@ -16,7 +19,13 @@ class BasicDataProcessor(object):
     def process_all(self, start_date, end_date):
         failed_tasks = []
 
-        failed_tasks.extend(self.basic_data_part1.process_all(start_date, end_date))
+        try:
+            failed_tasks.extend(self.basic_data_part1.process_all(start_date, end_date))
+        except Exception as e:
+            print(e)
+            traceback.print_exc()
+            failed_tasks.append('unknown in basic_data_part1')
+
         failed_tasks.extend(self.basic_fund_ret.process_all(end_date))
         failed_tasks.extend(self._style_analysis.process_all(start_date, end_date))
         failed_tasks.extend(self._barra_cne5_factor.process_all(start_date, end_date))
