@@ -31,7 +31,7 @@ class FundIndicatorProcessorGroup:
         'mmf': ['货币市场型基金'],
         'mix': ['平衡混合型基金', '灵活配置型基金'],
     }
-    _REPLACE_DICT = {'stock': 'csi_stockfund', 'bond': 'csi_boodfund', 'mmf': 'mmf', 'QDII': 'csi_f_qdii', 'mix': 'csi_f_hybrid'}
+    _REPLACE_DICT = {'stock': 'csi_stockfund', 'bond': 'national_debt', 'mmf': 'mmf', 'QDII': 'csi_f_qdii', 'mix': 'csi_f_hybrid'}
 
     def __init__(self, data_helper: DerivedDataHelper, data_cycle: int):
         self._data_helper = data_helper
@@ -51,8 +51,7 @@ class FundIndicatorProcessorGroup:
         # 获取待计算的基金列表
         self.fund_info: pd.DataFrame = self._basic_api.get_fund_info().drop(columns='_update_time')
         self._wind_class_2_dict = self.fund_info.set_index('fund_id')['wind_class_2'].to_dict()
-        self._fund_list: pd.DataFrame = self.fund_info[self.fund_info.structure_type <= 1]
-       
+        
         # 向前取N年
         start_date: str = (pd.to_datetime(end_date, infer_datetime_format=True) - DateOffset(years=self._data_cycle+1)).strftime('%Y%m%d')
         # 获取区间内交易日列表
@@ -63,7 +62,10 @@ class FundIndicatorProcessorGroup:
 
         # 基金净值数据、指数价格数据的index对齐到交易日列表
         _tm_loads_nav_0 = time.time()
-        fund_nav: pd.DataFrame = self._basic_api.get_fund_nav_with_date(start_date, end_date, self._fund_list.fund_id.tolist())  #, fund_list = f_l)
+        self._fund_list = self.fund_info[(self.fund_info.end_date > self.end_date) 
+                                       & (self.fund_info.structure_type <= 1)
+                                       & (~self.fund_info.wind_class_2.isnull())]
+        fund_nav: pd.DataFrame = self._basic_api.get_fund_nav_with_date(start_date, self.end_date, self._fund_list.fund_id.tolist())
         self._fund_nav_origin: pd.DataFrame = fund_nav.pivot_table(index='datetime', columns='fund_id', values='adjusted_net_value').reindex(self._trading_days.index).fillna(method='ffill')
         _tm_loads_nav_1 = time.time()
         # 选取成立满半年的 而且近半年波动率不为0，并排除掉异常净值基金
@@ -97,7 +99,8 @@ class FundIndicatorProcessorGroup:
 
             else:
                 self.abnormal_reason.append({'fund_id':fund_id,'abnormal_reason':'less_than_half_y'})
-        self._fund_nav = self._fund_nav_origin[normal_fund_list].copy()
+        # 全部计算 
+        self._fund_nav = self._fund_nav_origin.copy()#[normal_fund_list].copy()
         _tm_filter_nav = time.time()
         index_price: pd.DataFrame = self._basic_api.get_index_price_dt(start_date, end_date, columns=['close'])
         _tm_load_index = time.time()
@@ -378,7 +381,7 @@ class FundIndicatorProcessorGroup:
                     'beta_t':np.nan,
                     'beta_p':np.nan,
                     }
-        X = np.array([total[:, 0], total[:, 0]]).T
+        X = np.array([total[:, 1], total[:, 1]]).T
         X[:, 1][X[:, 1] > 0] = 0
         if np.count_nonzero(X[:, 1]) == 0:
             return {'beta':np.nan,
@@ -389,7 +392,7 @@ class FundIndicatorProcessorGroup:
                     'beta_p':np.nan,
                     }
         X[:, 0][X[:, 0] < 0] = 0
-        est2 = sm.OLS(total[:, 1], sm.add_constant(X, prepend=False)).fit()
+        est2 = sm.OLS(total[:, 0], sm.add_constant(X, prepend=False)).fit()
         return {'beta':est2.params[0] - est2.params[1],
                 'alpha':est2.params[-1],
                 'alpha_t':est2.tvalues[-1],
@@ -408,8 +411,8 @@ class FundIndicatorProcessorGroup:
                     'beta_t':np.nan,
                     'beta_p':np.nan,
                     }
-        X = np.array([total[:, 0], total[:, 0] * total[:, 0]]).T
-        est2 = sm.OLS(total[:, 1], sm.add_constant(X, prepend=False)).fit()
+        X = np.array([total[:, 1], total[:, 1] * total[:, 1]]).T
+        est2 = sm.OLS(total[:, 0], sm.add_constant(X, prepend=False)).fit()
         return {'beta':est2.params[1],
                 'alpha':est2.params[-1],
                 'alpha_t':est2.tvalues[-1],
@@ -427,9 +430,9 @@ class FundIndicatorProcessorGroup:
                     'beta_t':np.nan,
                     'beta_p':np.nan,
                     }
-        X = np.array([total[:, 0], total[:, 0]]).T
+        X = np.array([total[:, 1], total[:, 1]]).T
         X[:, 1][X[:, 1] < 0] = 0
-        est2 = sm.OLS(total[:, 1], sm.add_constant(X, prepend=False)).fit()
+        est2 = sm.OLS(total[:, 0], sm.add_constant(X, prepend=False)).fit()
         return {'beta':est2.params[1],
                 'alpha':est2.params[-1],
                 'alpha_t':est2.tvalues[-1],
@@ -735,6 +738,7 @@ class FundIndicatorProcessorGroup:
         _df['datetime'] = self.end_date
         self._result = pd.merge(left=self._result, right=_df, how='outer', on=['fund_id','datetime'])
         self._result['data_cycle'] = str(self._data_cycle) + 'Y'
+        self._result = self._result.replace({np.inf: np.nan, -np.inf: np.nan})
 
     def process(self, start_date: str, end_date: str, end_date_dt: datetime.date) -> List[str]:
         print(f'indicator group update on the last day of week {end_date_dt}')
