@@ -568,4 +568,32 @@ class ManagerProcessor:
         self.manager_indicator_score.to_parquet(f'{_s3_bucket_uri}/{name}.parquet', compression='gzip')
 
 if __name__ == '__main__':
-    pass
\ No newline at end of file
+    self = ManagerProcessor(DerivedDataApi())
+    start_date = '2005-01-01'
+    end_date = '2020-10-31'
+    self.init(start_date=start_date,end_date=end_date,is_mng_index=True)
+    self.calc_index()
+    
+    bucket_name = 'tl-fund-dm'
+    _s3_bucket_uri: str = f's3://{bucket_name}/dm'
+
+    name = 'mng_best_fund'
+    data = self.mng_best_fund
+    res_dict = {}
+    for k, df in data.items():
+        res_dict[k] = df.to_dict('index')
+    df = pd.DataFrame(res_dict)    
+    df.to_parquet(f'{_s3_bucket_uri}/{name}.parquet', compression='gzip')
+
+    name = 'mng_index_list'
+    data = self.mng_index_list
+    res_dict = {}
+    for k, df in data.items():
+        res_dict[k] = df.to_dict('index')
+    df = pd.DataFrame(res_dict)    
+    df.to_parquet(f'{_s3_bucket_uri}/{name}.parquet', compression='gzip')
+
+    self.calc_mng_indicator()
+    self.calc_score()
+    name = 'mng_indicator_score'
+    self.manager_indicator_score.to_parquet(f'{_s3_bucket_uri}/{name}.parquet', compression='gzip')
\ No newline at end of file
