@@ -102,7 +102,7 @@ class SynchronizerS3ForDM(S3ETLTool):
 
         failed_tables: List[str] = []
         for name, data in self._data_tables_dict.items():
-            if not isinstance(data, pd.DataFrame):
+            if not isinstance(data, pd.DataFrame) or (data is None):
                 # 这里不处理df以外的数据
                 continue
 
@@ -126,7 +126,7 @@ class SynchronizerS3ForDM(S3ETLTool):
         # dts部分
         failed_tables: List[str] = []
         for name, data in self._data_tables_dict.items():
-            if isinstance(data, pd.DataFrame):
+            if isinstance(data, pd.DataFrame) or (data is None):
                 # 这里只处理df以外的数据
                 continue
 
@@ -367,12 +367,19 @@ class S3RetrieverForDM(S3ETLTool):
             _t0 = time.time()
             try:
                 # 把我们保存的df转换回原来的类型
-                df = pd.read_parquet(f'{self._s3_bucket_uri}/_ndf_{name}.parquet')
                 if name in ('fund_list', 'all_fund_list', 'fund_ipo_list', 'fund_conv_list', 'index_list', 'index_date_list'):
+                    df = pd.read_parquet(f'{self._s3_bucket_uri}/_ndf_{name}.parquet')
                     data = set(df.to_dict(orient='list')[name])
                     if name == 'index_date_list':
                         data = sorted(data)
+                elif name in ('mng_best_fund','mng_index_list'):
+                    df = pd.read_parquet(f'{self._s3_bucket_uri}/{name}.parquet')
+                    data = {}
+                    for col in df:
+                        _df = df[[col]]
+                        data[col] = pd.DataFrame(_df[col].values.tolist(), index=_df.index)
                 elif name in ('fund_index_map', 'fund_end_date_dict'):
+                    df = pd.read_parquet(f'{self._s3_bucket_uri}/_ndf_{name}.parquet')
                     data = df.to_dict()[name]
                 else:
                     raise FileNotFoundError(f'do not support retrieve this data {name} from s3')
