@@ -47,7 +47,7 @@ def profiled(file_name=None):
 
 class FundDataManager(DataManager):
 
-    _BLOCK_DF_LIST = ('fund_manager_score', 'fund_indicator')
+    _BLOCK_DF_LIST = ['fund_manager_score']
 
     def __init__(self, start_time=None, end_time=None, fund_score_param: FundScoreParam = None, score_manager: FundScoreManager = None, s3_retriever_activation: Optional[List[str]] = None):
         DataManager.__init__(self,
