@@ -678,4 +678,16 @@ class BondInFund(Base):
     bond_name = Column(CHAR(64)) # 债券名称
     bond_weight = Column(DOUBLE(asdecimal=False)) # 债券在基金权重
     fund_name = Column(CHAR(64)) # 基金名称
-    
\ No newline at end of file
+    
+class ETFInfo(Base):
+
+    __tablename__ = 'etf_info'
+
+    fund_id = Column(CHAR(10), primary_key=True)  # 基金代码
+    desc_name = Column(CHAR(64)) # 基金名称
+    wind_class_1 = Column(CHAR(64)) # Wind基金类型
+    wind_class_2 = Column(CHAR(64)) # Wind基金二级类型
+    index_id = Column(CHAR(20)) # 指数id
+    company_id = Column(CHAR(64)) # 基金公司
+    etf_type = Column(CHAR(10)) # 场内场外类型
+    index_name = Column(CHAR(64)) # 指数名称
\ No newline at end of file
