@@ -505,6 +505,8 @@ class FundRecommendationCollection(Base):
     mng_id = Column(CHAR(64)) # 基金经理id
     mng_name = Column(CHAR(64)) # 基金经理名字
     fund_type = Column(CHAR(64)) # 基金大类类型
+    is_abs_ret_fund = Column(TINYINT(1)) # 是否是绝对收益基金 0 否， 1 是
+    is_conv_bond_fund = Column(TINYINT(1)) # 是否是可转债基金 0 否， 1 是
 
     @staticmethod
     def trans_columns():
@@ -532,6 +534,8 @@ class FundRecommendationCollection(Base):
             'total_score': '基金总分',
             'mng_id': '基金经理id',
             'mng_name': '基金经理名字',
+            'is_abs_ret_fund': '是否是绝对收益基金',
+            'is_conv_bond_fund': '是否是可转债基金',
             'fund_type': '基金大类类型',
         }
 
