@@ -48,7 +48,7 @@ class FundEngine:
         assert not self.is_fund_backtest or self._fa_helper, 'if this is a fund backtest, fa_helper is necessary'
         if self.is_fund_backtest:
             self._trader.set_helper(self._fa_helper)
-        self.score_select = ScoreSelect.__dict__ if score_select is None else score_select.__dict__
+        self.score_select = ScoreSelect().__dict__ if score_select is None else score_select.__dict__
         if fund_score_funcs is not None:
             for index_id in fund_score_funcs:
                 self.score_select[index_id] = ScoreType.Temp
@@ -119,7 +119,7 @@ class FundEngine:
                 v_asset_position, asset_trade_list = self._trader.calc_asset_trade(dt, cur_asset_position, self._prep_asset_price, self._prep_target_asset_allocation)
                 expired_con = self._trader.has_expired_fund(cur_fund_position, self._prep_fund_score )
                 if asset_trade_list or expired_con:
-                    self._report_helper.update_rebalance_detail(dt, expired_con)
+                    self._report_helper.update_rebalance_detail(dt, expired_con, {})
                     v_fund_position, fund_trade_list = self._trader.calc_fund_trade(
                         dt, self._prep_target_fund_allocation, cur_fund_position, self._prep_fund_nav, 
                         self._prep_fund_purchase_fees, self._prep_fund_redeem_fees
@@ -129,13 +129,13 @@ class FundEngine:
                     return None
             assert cur_fund_position, 'cur_fund_position should not be None in fund backtest run'
             assert self._prep_target_fund_allocation, 'target fund allocation should be prepared already'
-            v_fund_position, fund_trade_list, trigger_reason = self._trader.calc_trade(
+            v_fund_position, fund_trade_list, trigger_reason, trigger_detail = self._trader.calc_trade(
                 dt, self._prep_target_fund_allocation, self._prep_target_asset_allocation,
                 cur_fund_position, cur_asset_position, 
                 self._prep_fund_nav, self._prep_fund_score, self._prep_asset_price,self._prep_fund_unit_nav, 
                 is_real_trade, self._prep_manager_funds, self.score_select, self._prep_fund_end_date_dict
             )
-            self._report_helper.update_rebalance_detail(dt, trigger_reason)
+            self._report_helper.update_rebalance_detail(dt, trigger_reason, trigger_detail)
             return fund_trade_list
 
     def finalize_trade(self, dt, trades: list, cur_asset_position: AssetPosition, cur_fund_position: FundPosition=None, disproved_set: set={}):
@@ -334,7 +334,7 @@ class BasicFundBacktestEngine(object):
 
             curr_target_fund_weight.add(FundWeightItem(fund_id=fund_id, fund_wgt=weight, 
                                                        index_id=index_id, asset_wgt=0, fund_wgt_in_asset=0))
-        self._report_helper.update_rebalance_detail(dt, 'Change fund weight')
+        self._report_helper.update_rebalance_detail(dt, 'Change fund weight',{})
         v_fund_position, fund_trade_list = self._trader.calc_fund_trade(
             dt, curr_target_fund_weight, cur_fund_position, self._prep_fund_nav, 
             self._prep_fund_purchase_fees, self._prep_fund_redeem_fees)
@@ -536,7 +536,7 @@ class AIPFundBackTestEngine(BasicFundBacktestEngine):
         self.deposits.append(cash)
         self.current_deposit = cash
 
-        self._report_helper.update_rebalance_detail(dt, 'Change fund weight')
+        self._report_helper.update_rebalance_detail(dt, 'Change fund weight', {})
         v_fund_position, fund_trade_list = self._trader.calc_fund_trade(
             dt, curr_target_fund_weight, new_fund_position, self._prep_fund_nav,
             self._prep_fund_purchase_fees, self._prep_fund_redeem_fees)
@@ -656,7 +656,7 @@ def four_dimensions_backtest(m,begin_date, end_date, saa, fund_param, taa_detail
         res_i = Calculator.get_stat_result_from_df(df=mv_df.reset_index(), date_column='date', value_column=port_name).__dict__
         res_i['策略名称'] = port_name
         res.append(res_i)
-    stat_df = pd.DataFrame(res).set_index('策略名称').reindex(['沪深300','战略配置','战术配置','优选基金'])[['annualized_ret','annualized_vol','sharpe','mdd','mdd_date1','mdd_date2']]
+    stat_df = pd.DataFrame(res).set_index('策略名称').reindex(['沪深300','战略配置','战术配置','优选基金'])#[['annualized_ret','annualized_vol','sharpe','mdd','mdd_date1','mdd_date2']]
     return mv_df, stat_df, fund_annual_ret
 
 def licaimofang_backtest(m: FundDataManager, saa:AssetWeight):
