@@ -109,22 +109,24 @@ class HybridPainter(object):
             mdd_lens2 = mdd_lens3
              
         index_df_raw = index_price.loc[mv_df.index[0]:mv_df.index[-1],]
-        index_df = index_df_raw.copy().fillna(method='bfill')
-        index_df = index_df / index_df.iloc[0]
-        index_df['cash'] = 1
-        w_l = []
-        for idx, r in index_df_raw.iterrows():
-            nan_asset = [k for k, v in r.to_dict().items() if np.isnan(v)]
-            wgts = saa_weight.copy()
-            for k in nan_asset:
-                wgts[k] = 0
-            s = sum([v  for k,v in wgts.items()])
-            wgts = {k :v /s for k, v in wgts.items()}
-            wgts['datetime'] = idx
-            w_l.append(wgts)
-        wgts_df = pd.DataFrame(w_l).set_index('datetime')
-        mv_df['benchmark'] = (wgts_df * index_df).sum(axis = 1)
+        date_list = [datetime.datetime.strptime(i, '%Y-%m-%d').date() for i in bk_stats['hold_years']]
+        date_list = sorted(list(set(date_list + [mv_df.index[-1]])))
+        saa_weight = { k : v for k, v in saa_weight.items() if v > 0}
+        _res = []
+        last_value = 1
+        for dt in date_list[:-1]:
+            next_dt = date_list[date_list.index(dt) + 1]
+            _df = index_df_raw.loc[dt:next_dt][list(saa_weight.keys())]
+            _df = _df / _df.iloc[0]
+            res_i = (_df * saa_weight).sum(axis=1)
+            res_i = res_i * last_value
+            last_value = res_i.values[-1]
+            _res.append(res_i)
+        benchmark_df = pd.concat(_res,axis=0)
+        mv_df = mv_df.join(pd.DataFrame(benchmark_df,columns=['benchmark'])).bfill()
+        mv_df = mv_df.drop_duplicates()
         df = mv_df / mv_df.iloc[0]
+        df.index.name = 'date'
         fig, ax = plt.subplots(figsize= [20,12])
         df['price_ratio'] = df['mv'] / df['benchmark']       
         plt.plot(df.index, df['mv'], label = 'mv', linewidth=2.0)
@@ -150,6 +152,7 @@ class HybridPainter(object):
         plot_mdd_recover(mdd_date1_1, mdd_date1_2, df, 'silver', ax)
         plot_mdd_recover(mdd_date2_1, mdd_date2_2, df, 'gainsboro', ax)
         plt.grid() 
+        #plt.savefig("test.svg")
         plt.show()
 
     @staticmethod
