@@ -85,6 +85,7 @@ class ReportHelper:
         self.fund_score_raw = {}
         self.target_allocation = {}
         self._rebalance_details = []
+        self._rebalance_history = []
 
     def update(self,dt:datetime, asset_cur_position:AssetPosition, asset_cur_price:AssetPrice, pend_trades:list, fund_cur_position:FundPosition, fund_nav:dict, traded_list:list, fund_score:dict, fund_score_raw:dict, target_allocation):   
         # 检查回测时使用
@@ -151,7 +152,13 @@ class ReportHelper:
         w['annual_ret'] = res.annualized_ret #float
         w['ret_over_mdd'] = res.ret_over_mdd #float
         w['sharpe'] = res.sharpe #float 
+        w['recent_1m_ret'] = res.recent_1m_ret #float
+        w['recent_3m_ret'] = res.recent_3m_ret #float
+        w['recent_6m_ret'] = res.recent_6m_ret #float
+        w['recent_1y_ret'] = res.recent_y1_ret #float
         w['5_year_ret'] = res.recent_y5_ret #float
+        w['3_year_ret'] = res.recent_y3_ret #float
+        w['1_year_ret'] = res.recent_y1_ret #float
         w['annual_vol'] = res.annualized_vol #float
         w['mdd_d1'] = res.mdd_date1 #datetime
         w['mdd_d2'] = res.mdd_date2 #datetime
@@ -172,6 +179,7 @@ class ReportHelper:
         w['market_value'] = df #dataframe
         w['rebalance_times'] = len(self.rebalance_date)
         w['recent_drawdown'] = res.recent_drawdown
+        w['recent_mdd_date1'] = str(res.recent_mdd_date1) # str
         w['worst_3m_ret'] = res.worst_3m_ret
         w['worst_6m_ret'] = res.worst_6m_ret
         hold_days = self.rebalance_date + [df.index.values[-1]]
@@ -445,9 +453,10 @@ class ReportHelper:
             self.asset_mv.to_csv(csv_title + '_asset_mv.csv')
         self.get_asset_trade().to_csv(csv_title + '_asset_trade.csv')
     
-    def update_rebalance_detail(self, dt, rebalance_reason):
+    def update_rebalance_detail(self, dt, rebalance_reason, trigger_detail):
         if bool(rebalance_reason):
             self._rebalance_details.append({'datetime':dt,'rebalance_reason':rebalance_reason})
+        self._rebalance_history.append({'datetime':dt,'rebalance_reason':trigger_detail})
 
     def plot_taa_pct_df(self, dt):
         res = []
@@ -699,8 +708,11 @@ class ReportHelper:
             df_2 = _res_df[1]
             df_2 = df_1.iloc[-1] * df_2
             res_index_df = df_1.iloc[:-1].append(df_2, sort=True)
-        AssetPainter.plot_index_price_ratio(res_index_df,'price_ratio')
-        return res_df[['begin_date','end_date','desc_name','index_id','weight','rets']]
+        AssetPainter.plot_index_price_ratio(res_index_df.dropna(),'price_ratio')
+        res_df = res_df.rename(columns={'ret':'fund_ret'})
+        res_df['fund_ret'] = res_df.fund_ret.map(lambda x: str(round(x*100,2)) +'%')
+        res_df['weight'] = res_df.weight.map(lambda x: str(round(x*100,2)) +'%')
+        return res_df[['begin_date','end_date','desc_name','index_id','fund_ret','weight','rets']]
 
     @staticmethod
     def rolling_analysis(rolling_year, index_id, m, mv_df, fund_annual_ret, ret_list=[]):
